==> monocdk-1.106.1.tar.gz: package/lib/aws-autoscaling/lib/autoscaling-canned-metrics.generated.d.ts <==
export declare class AutoScalingMetrics {
    static groupTotalInstancesAverage(dimensions: {
        AutoScalingGroupName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            AutoScalingGroupName: string;
        };
        statistic: string;
    };
    static groupDesiredCapacityAverage(dimensions: {
        AutoScalingGroupName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            AutoScalingGroupName: string;
        };
        statistic: string;
    };
    static groupMaxSizeAverage(dimensions: {
        AutoScalingGroupName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            AutoScalingGroupName: string;
        };
        statistic: string;
    };
    static groupMinSizeAverage(dimensions: {
        AutoScalingGroupName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            AutoScalingGroupName: string;
        };
        statistic: string;
    };
    static groupTerminatingInstancesAverage(dimensions: {
        AutoScalingGroupName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            AutoScalingGroupName: string;
        };
        statistic: string;
    };
    static groupPendingInstancesAverage(dimensions: {
        AutoScalingGroupName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            AutoScalingGroupName: string;
        };
        statistic: string;
    };
    static groupInServiceInstancesAverage(dimensions: {
        AutoScalingGroupName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            AutoScalingGroupName: string;
        };
        statistic: string;
    };
    static groupStandbyInstancesAverage(dimensions: {
        AutoScalingGroupName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            AutoScalingGroupName: string;
        };
        statistic: string;
    };
}

==> monocdk-1.185.0.tar.gz: package/lib/aws-autoscaling/lib/autoscaling-canned-metrics.generated.d.ts <==
export declare class AutoScalingMetrics {
    static groupTotalInstancesAverage(dimensions: {
        AutoScalingGroupName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            AutoScalingGroupName: string;
        };
        statistic: string;
    };
    static groupDesiredCapacityAverage(dimensions: {
        AutoScalingGroupName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            AutoScalingGroupName: string;
        };
        statistic: string;
    };
    static groupMaxSizeAverage(dimensions: {
        AutoScalingGroupName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            AutoScalingGroupName: string;
        };
        statistic: string;
    };
    static groupMinSizeAverage(dimensions: {
        AutoScalingGroupName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            AutoScalingGroupName: string;
        };
        statistic: string;
    };
    static groupTerminatingInstancesAverage(dimensions: {
        AutoScalingGroupName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            AutoScalingGroupName: string;
        };
        statistic: string;
    };
    static groupPendingInstancesAverage(dimensions: {
        AutoScalingGroupName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            AutoScalingGroupName: string;
        };
        statistic: string;
    };
    static groupInServiceInstancesAverage(dimensions: {
        AutoScalingGroupName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            AutoScalingGroupName: string;
        };
        statistic: string;
    };
    static groupStandbyInstancesAverage(dimensions: {
        AutoScalingGroupName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            AutoScalingGroupName: string;
        };
        statistic: string;
    };
}
